A python client to Service Now API. This project is a fork of Parul Neeraj 
project (https://pypi.org/project/servicenow-client/).

# Examples of usage:  
 ## Init client
  ### Params: 
  - String instance: if your instance is test.service-now.com use test 
  - String user: user name 
  - String password: password      
    > **E.g.:**  service_now_client = ServiceNowClient(instance, user, password)